@@ -488,7 +488,8 @@ serialize(PyObject *module, PyObject *a)
 
     str = PyBytes_AsString(result);
 #define aa  ((bitarrayobject *) a)
-    *str = (IS_BE(aa) ? 0x10 : 0x00) | ((char) set_padbits(aa));
+    set_padbits(aa);
+    *str = (IS_BE(aa) ? 0x10 : 0x00) | ((char) PADBITS(aa));
     memcpy(str + 1, aa->ob_item, (size_t) nbytes);
 #undef aa
     return result;
@@ -1055,8 +1056,7 @@ byte_length(Py_ssize_t i)
    BSI(1) = 32 must be divisible by SEGSIZE.
    SEGSIZE must also be a multiple of the word size (sizeof(uint64_t) = 8).
    The size 32 is rooted in the fact that a bitarray of 32 bytes (256 bits)
-   can be indexed with one index byte (BSI(1) = 32).  Our entire 'sc' format
-   is constructed around this. */
+   can be indexed with one index byte (BSI(1) = 32). */
 #define SEGSIZE  32
 
 /* number of segments for given number of bits */
@@ -1322,9 +1322,8 @@ sc_write_sparse(char *str, bitarrayobject *a, Py_ssize_t *rts,
    Notes:
 
    - 32 index bytes take up as much space as a raw buffer of 32 bytes.
-     Hence, we start by counting up to 32 bits in the first 32 bytes of the
-     bitarray buffer in order to decide whether a raw block (type 0) should
-     be used.
+     Hence, if the bit count of the first 32 bytes of the bitarray buffer
+     is greater or equal to 32, we choose a raw block (type 0).
 
    - If a raw block is used, we check if the next three 32 byte buffer
      blocks are also suitable for raw encoding, see write_raw_block().
@@ -1415,6 +1414,7 @@ sc_encode(PyObject *module, PyObject *obj)
     bitarrayobject *a;
     Py_ssize_t offset = 0;      /* block offset into bitarray `a` in bytes */
     Py_ssize_t *rts;            /* running totals for 256 bit segments */
+    Py_ssize_t t;               /* total population count of bitarray `a` */
 
     if (ensure_bitarray(obj) < 0)
         return NULL;
@@ -1431,14 +1431,18 @@ sc_encode(PyObject *module, PyObject *obj)
     str = PyBytes_AS_STRING(out);
     len += sc_encode_header(str, a);
 
-    while (offset < Py_SIZE(a)) {
+    t = rts[NSEG(a->nbits)];
+    /* encode blocks as long as we haven't reached the end of the bitarray
+       and haven't reached the total population count yet */
+    while (offset < Py_SIZE(a) && rts[offset / SEGSIZE] != t) {
         Py_ssize_t allocated;   /* size (in bytes) of output buffer */
 
         /* Make sure we have enough space in output buffer for next block.
            The largest block possible is a type 4 block with 255 indices.
-           It's size is: 2 header bytes + 4 * 255 index bytes */
+           It's size is: 2 header bytes + 4 * 255 index bytes.
+           Plus, we also may have the stop byte. */
         allocated = PyBytes_GET_SIZE(out);
-        if (allocated < len + 2 + 4 * 255) {  /* increase allocation */
+        if (allocated < len + 2 + 4 * 255 + 1) {  /* increase allocation */
             if (_PyBytes_Resize(&out, allocated + 32768) < 0)
                 return NULL;
             str = PyBytes_AS_STRING(out);
@@ -1498,6 +1502,7 @@ sc_read_raw(bitarrayobject *a, Py_ssize_t offset, PyObject *iter, int k)
     char *buff = a->ob_item + offset;
     Py_ssize_t i;
 
+    assert(1 <= k && k <= 128);
     if (offset + k > Py_SIZE(a)) {
         PyErr_Format(PyExc_ValueError, "decode error (raw): %zd + %d > %zd",
                      offset, k, Py_SIZE(a));
@@ -1560,7 +1565,7 @@ sc_decode_block(bitarrayobject *a, Py_ssize_t offset, PyObject *iter)
     if (0xc2 <= head && head <= 0xc4) {    /* type 2 .. 4 - 0xc2 .. 0xc4 */
         int k;
 
-        if ((k = next_char(iter)) < 0)
+        if ((k = next_char(iter)) < 0)     /* index count byte */
             return -1;
 
         return sc_read_sparse(a, offset, iter, head - 0xc0, k);
