@@ -39,8 +39,6 @@ if sys.version_info[0] == 3:
 else:
     from io import BytesIO as StringIO
 
-tests = []  # type: list
-
 # ---------------------------------------------------------------------------
 
 class TestsZeros(unittest.TestCase):
@@ -80,8 +78,6 @@ class TestsZeros(unittest.TestCase):
         # endian wrong string
         self.assertRaises(ValueError, zeros, 0, 'foo')
 
-tests.append(TestsZeros)
-
 # ---------------------------------------------------------------------------
 
 class TestsURandom(unittest.TestCase):
@@ -122,8 +118,6 @@ class TestsURandom(unittest.TestCase):
         self.assertRaises(TypeError, urandom, 0, 1)
         self.assertRaises(ValueError, urandom, 0, 'foo')
 
-tests.append(TestsURandom)
-
 # ---------------------------------------------------------------------------
 
 class TestsPPrint(unittest.TestCase):
@@ -195,8 +189,6 @@ class TestsPPrint(unittest.TestCase):
         finally:
             shutil.rmtree(tmpdir)
 
-tests.append(TestsPPrint)
-
 # ---------------------------------------------------------------------------
 
 class TestsMakeEndian(unittest.TestCase, Util):
@@ -242,8 +234,6 @@ class TestsMakeEndian(unittest.TestCase, Util):
                     self.assertTrue(b is a)
             self.assertEQUAL(a, aa)
 
-tests.append(TestsMakeEndian)
-
 # ---------------------------------------------------------------------------
 
 class TestsRIndex(unittest.TestCase, Util):
@@ -349,8 +339,6 @@ class TestsRIndex(unittest.TestCase, Util):
             a[randint(0, N - 1)] = 1
             self.assertEqual(rindex(a), a.index(1))
 
-tests.append(TestsRIndex)
-
 # ---------------------------------------------------------------------------
 
 class TestsStrip(unittest.TestCase, Util):
@@ -413,8 +401,6 @@ class TestsStrip(unittest.TestCase, Util):
             self.assertEqual(strip(a, 'both'), bitarray('1'))
             self.assertEqual(len(a), n)
 
-tests.append(TestsStrip)
-
 # ---------------------------------------------------------------------------
 
 class TestsCount_N(unittest.TestCase, Util):
@@ -568,8 +554,6 @@ class TestsCount_N(unittest.TestCase, Util):
                 # n = 0 -> count_n always 0
                 self.assertEqual(count_n(a, 0, v), 0)
 
-tests.append(TestsCount_N)
-
 # ---------------------------------------------------------------------------
 
 class TestsBitwiseCount(unittest.TestCase, Util):
@@ -659,8 +643,6 @@ class TestsBitwiseCount(unittest.TestCase, Util):
             self.assertEqual(all(a ^ b), count_xor(a, b) == n)
             self.assertEqual(all(a ^ b), a == ~b)
 
-tests.append(TestsBitwiseCount)
-
 # ---------------------------------------------------------------------------
 
 class TestsBitwiseAny(unittest.TestCase, Util):
@@ -712,8 +694,6 @@ class TestsBitwiseAny(unittest.TestCase, Util):
             a[i] = 1
             self.assertEqual(b[i], any_and(a, b))
 
-tests.append(TestsBitwiseAny)
-
 # ---------------------------------------------------------------------------
 
 class TestsSubset(unittest.TestCase, Util):
@@ -763,8 +743,6 @@ class TestsSubset(unittest.TestCase, Util):
             a.setall(1)
             self.check(b, a, True)
 
-tests.append(TestsSubset)
-
 # ---------------------------------------------------------------------------
 
 class TestsCorrespondAll(unittest.TestCase, Util):
@@ -802,8 +780,6 @@ class TestsCorrespondAll(unittest.TestCase, Util):
             self.assertEqual(res[1] + res[2], count_xor(a, b))
             self.assertEqual(sum(res), n)
 
-tests.append(TestsCorrespondAll)
-
 # ---------------------------------------------------------------------------
 
 class TestsParity(unittest.TestCase, Util):
@@ -842,8 +818,6 @@ class TestsParity(unittest.TestCase, Util):
             self.assertEqual(parity(a), a.count() % 2)
             self.assertEqual(a, b)
 
-tests.append(TestsParity)
-
 # ---------------------------------------------------------------------------
 
 class TestsIntervals(unittest.TestCase, Util):
@@ -904,8 +878,6 @@ class TestsIntervals(unittest.TestCase, Util):
 
             self.assertEqual(a, b)
 
-tests.append(TestsIntervals)
-
 # ---------------------------------------------------------------------------
 
 class TestsHexlify(unittest.TestCase, Util):
@@ -1000,8 +972,6 @@ class TestsHexlify(unittest.TestCase, Util):
         b.frombytes(binascii.unhexlify(s))
         self.assertEQUAL(hex2ba(s, 'big'), b)
 
-tests.append(TestsHexlify)
-
 # ---------------------------------------------------------------------------
 
 class TestsBase(unittest.TestCase, Util):
@@ -1160,8 +1130,6 @@ class TestsBase(unittest.TestCase, Util):
                 b = bitarray(a, 'big')
                 self.assertEQUAL(base2ba(n, ba2base(n, b), 'big'), b)
 
-tests.append(TestsBase)
-
 # ---------------------------------------------------------------------------
 
 class SC_Tests(unittest.TestCase, Util):
@@ -1392,11 +1360,15 @@ class SC_Tests(unittest.TestCase, Util):
             a.setall(0)
             m = 2                            # head byte and stop byte
             m += bits2bytes(n.bit_length())  # size bytes
-            # For smaller or equal to 1 << 32, we have only one type 4 block.
-            m += bool(n > 0)                 # number of blocks (head bytes)
-            m += bool(n > 256)               # number of second block heads
-            b = sc_encode(a)
-            self.assertEqual(m, len(b))
+            #print(i, n, m, sc_encode(a))
+            self.assertEqual(m, len(sc_encode(a)))
+            self.round_trip(a)
+
+            a[0] = 1
+            m += 2                  # block head byte and one index byte
+            m += 2 * bool(n > 512)  # second block head and second index byte
+            m += bool(n > 65536)    # third index byte
+            self.assertEqual(m, len(sc_encode(a)))
             self.round_trip(a)
 
         a = zeros(1 << 25, 'big')
@@ -1457,8 +1429,6 @@ class SC_Tests(unittest.TestCase, Util):
                 seg_pop = a.count(1, segbits * i, segbits * (i + 1))
                 self.assertEqual(rts[i + 1] - rts[i], seg_pop)
 
-tests.append(SC_Tests)
-
 # ---------------------------------------------------------------------------
 
 class VLFTests(unittest.TestCase, Util):
@@ -1605,8 +1575,6 @@ class VLFTests(unittest.TestCase, Util):
         for a in self.randombitarrays():
             self.round_trip(a)
 
-tests.append(VLFTests)
-
 # ---------------------------------------------------------------------------
 
 class TestsIntegerization(unittest.TestCase, Util):
@@ -1804,8 +1772,6 @@ class TestsIntegerization(unittest.TestCase, Util):
 
             self.assertEqual(i, self.twos_complement(j, len(a)))
 
-tests.append(TestsIntegerization)
-
 # ---------------------------------------------------------------------------
 
 class MixedTests(unittest.TestCase, Util):
@@ -1904,8 +1870,6 @@ class MixedTests(unittest.TestCase, Util):
         # the 1000th prime is 7919
         self.assertEqual(count_n(sieve, 1000) - 1, 7919)
 
-tests.append(MixedTests)
-
 # ---------------------------------------------------------------------------
 
 class TestsSerialization(unittest.TestCase, Util):
@@ -2004,8 +1968,6 @@ class TestsSerialization(unittest.TestCase, Util):
             self.assertEqual(a.endian(), c.endian())
             self.check_obj(c)
 
-tests.append(TestsSerialization)
-
 # ---------------------------------------------------------------------------
 
 class TestsHuffman(unittest.TestCase):
@@ -2101,8 +2063,6 @@ class TestsHuffman(unittest.TestCase):
             code = huffman_code({i: random() for i in range(n)})
             self.check_tree(code)
 
-tests.append(TestsHuffman)
-
 # ---------------------------------------------------------------------------
 
 class TestsCanonicalHuffman(unittest.TestCase, Util):
@@ -2360,25 +2320,7 @@ class TestsCanonicalHuffman(unittest.TestCase, Util):
             freq = {i: random() for i in range(n)}
             self.check_code(*canonical_huffman(freq))
 
-
-tests.append(TestsCanonicalHuffman)
-
 # ---------------------------------------------------------------------------
 
-def run(verbosity=1):
-    import bitarray
-
-    print('bitarray.util is installed in: %s' % os.path.dirname(__file__))
-    print('bitarray version: %s' % bitarray.__version__)
-    print('Python version: %s' % sys.version)
-
-    suite = unittest.TestSuite()
-    for cls in tests:
-        suite.addTest(unittest.makeSuite(cls))
-
-    runner = unittest.TextTestRunner(verbosity=verbosity)
-    return runner.run(suite)
-
-
 if __name__ == '__main__':
-    run()
+    unittest.main()
